==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/cenzor/translations/cenzor_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Cenzor</source>
        <translation>Cenzor</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Enable cenzor</source>
        <translation>Povolit cenzora</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation>Napomenutí</translation>
    </message>
    <message>
        <source>Swearwords</source>
        <translation>Sprostá slova</translation>
    </message>
    <message>
        <source>Exclusions</source>
        <translation>Výjimky</translation>
    </message>
    <message>
        <source>Message was cenzored</source>
        <translation>Zpráva byla zcenzůrována</translation>
    </message>
</context>
<context>
    <name>CenzorNotification</name>
    <message>
        <source>Message was cenzored</source>
        <translation>Zpráva byla zcenzůrována</translation>
    </message>
    <message>
        <source>Your interlocutor used obscene word and became admonished</source>
        <translation>Účastník vaší rozmluvy použil sprosté slovo a byl za to vykázán</translation>
    </message>
    <message>
        <source>Cenzor</source>
        <translation>Cenzor</translation>
    </message>
</context>
<context>
    <name>ListEditWidget</name>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Změnit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/cenzor/translations/cenzor_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Cenzor</source>
        <translation>Cenzor</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Enable cenzor</source>
        <translation>Povolit cenzora</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation>Napomenutí</translation>
    </message>
    <message>
        <source>Swearwords</source>
        <translation>Sprostá slova</translation>
    </message>
    <message>
        <source>Exclusions</source>
        <translation>Výjimky</translation>
    </message>
    <message>
        <source>Message was cenzored</source>
        <translation>Zpráva byla zcenzůrována</translation>
    </message>
</context>
<context>
    <name>CenzorNotification</name>
    <message>
        <source>Message was cenzored</source>
        <translation>Zpráva byla zcenzůrována</translation>
    </message>
    <message>
        <source>Your interlocutor used obscene word and became admonished</source>
        <translation>Účastník vaší rozmluvy použil sprosté slovo a byl za to vykázán</translation>
    </message>
    <message>
        <source>Cenzor</source>
        <translation>Cenzor</translation>
    </message>
</context>
<context>
    <name>ListEditWidget</name>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Změnit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
</TS>
